Package: geneNR
Title: Automated Gene Identification for Post-GWAS and QTL Analysis
Version: 3.0.0
Authors@R: c(person("Rajamani", "Nirmalaruban", role = c("aut", "cre", "cph"), email = "nirmalaruban97@gmail.com"),
              person("R.", "Suvitha", role = "aut", email = "suvitha59528@gmail.com"),
              person("Rajbir", "Yadav", role = "aut", email = "rajbiryadav@yahoo.com"),
              person("Meda", "Alekya", role = "aut", email = "alekyameda210pink@gmail.com"), 
              person("Amit Kumar", "Mazumder", role = "aut", email = "amitkumarmazumder434@gmail.com"),
              person("Thirumurugan", "Sathya", role = "aut", email = "sathyasuba96@gmail.com"),
              person("Subramani", "Sugumar", role = "aut", email = "sugustays@gmail.com"),
              person("Prashanth", "babu", role = "aut", email = "prashanthbabuh@gmail.com"),
              person("Manjeet", "Kumar", role = "aut", email = "manjeetbhu615@gmail.com"),
              person("Kiran B", "Gaikwad", role = "aut", email = "gaikwadkb@gmail.com"),
              person("Naresh Kumar", "Bainsla", role = "aut", email = "Bainsla.breeder.icar@gmail.com"),
              person("S.", "Bhaskar Reddy", role = "aut", email = "bhaskarreddy1996@gmail.com"))
Description: Facilitates the post-Genome Wide Association Studies (GWAS) and Quantitative Trait Loci (QTL) analysis of identifying candidate genes within user-defined search window, based on the identified Single Nucleotide Polymorphisms (SNPs) as given by Mazumder AK (2024) <doi:10.1038/s41598-024-66903-3>. It supports candidate gene analysis for wheat and rice. Just import your GWAS result as explained in the sample_data file and the function does all the manual search and retrieve candidate genes for you, while exporting the results into ready-to-use output.
License: CC BY 4.0
Copyright: (C) 2026 Nirmalaruban
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 3.5)
LazyData: TRUE
Imports: readr, stringr, utils, httr, rvest, xml2, writexl, vcfR,
        ggplot2, ggrepel
Suggests: knitr, rmarkdown, devtools
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-07-05 14:43:54 UTC; nirma
Author: Rajamani Nirmalaruban [aut, cre, cph],
  R. Suvitha [aut],
  Rajbir Yadav [aut],
  Meda Alekya [aut],
  Amit Kumar Mazumder [aut],
  Thirumurugan Sathya [aut],
  Subramani Sugumar [aut],
  Prashanth babu [aut],
  Manjeet Kumar [aut],
  Kiran B Gaikwad [aut],
  Naresh Kumar Bainsla [aut],
  S. Bhaskar Reddy [aut]
Maintainer: Rajamani Nirmalaruban <nirmalaruban97@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-05 15:10:02 UTC
