# Generated by roxygen2: do not edit by hand

export(geneQTL)
export(geneSNP)
export(geneSNPcustom)
export(import_hmp)
export(import_vcf)
export(plot_SNP)
export(plot_summariseSNP)
export(summariseSNP)
export(summariseSNP_vcf)
