#' Sample Data
#'
#' A dataset containing sample data related to genetic markers and associated traits.
#'
#' @format A data frame with columns:
#' \describe{
#'   \item{traits}{Associated traits, character.}
#'   \item{Chr}{Chromosome location, character.}
#'   \item{start}{Position on the chromosome where QTL starts, numeric.}
#'   \item{stop}{Position on the chromosome where QTL stops, numeric.}
#'
#' }
#' @source {Generated for demonstration purposes}
#' @examples
#' data(sample_data_rice_qtl)    #lazy loading
"sample_data_rice_qtl"
