% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geneSNPcustom.R
\name{geneSNPcustom}
\alias{geneSNPcustom}
\title{Identifies Candidate Genes based on identified Single Nucleotide Polymorphisms (SNPs) from Genome Wide Association Studies (GWAS) Analysis}
\usage{
geneSNPcustom(
  data_file,
  crop = "wheat",
  genome_source = "online",
  gff3_file = NULL
)
}
\arguments{
\item{data_file}{The input data in .csv format. (sample_data_wheat_custom for demo purpose)}

\item{crop}{Either "wheat" or "rice". (default: wheat)}

\item{genome_source}{Character specifying either "online" (default Ensembl lookup) or "local" (uses a local GFF3 file).}

\item{gff3_file}{Path to a local custom .gff3 file. Only utilized if genome_source = "local".}
}
\value{
A data frame containing traits, SNP, search_window, gene_size, gene_id, and gene_type.
}
\description{
Identifies Candidate Genes based on identified Single Nucleotide Polymorphisms (SNPs) from Genome Wide Association Studies (GWAS) Analysis
}
\examples{
load(system.file("extdata", "precomputed_sample_results_custom.rda", package = "geneNR"))
message(sample_results)
\dontrun{
result <- geneSNPcustom("sample_data_wheat_custom", crop = "wheat")
}
}
