% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geneQTL.R
\name{geneQTL}
\alias{geneQTL}
\title{Identifies Candidate Genes based on identified Quantitative Trait Loci (QTL) analysis}
\usage{
geneQTL(data_file, crop = "wheat", genome_source = "online", gff3_file = NULL)
}
\arguments{
\item{data_file}{The input data in .csv format. (sample_data_wheat_qtl or sample_data_rice_qtl for demo purpose)}

\item{crop}{Either "wheat" or "rice". (by default it will be wheat)}

\item{genome_source}{Character specifying either "online" (default Ensembl lookup) or "local" (uses a local GFF3 file).}

\item{gff3_file}{Path to a local custom .gff3 file. Only utilized if genome_source = "local".}
}
\value{
A data frame containing traits, QTL, gene_id, gene_size, and gene_type.
}
\description{
Identifies Candidate Genes based on identified Quantitative Trait Loci (QTL) analysis
}
\examples{
load(system.file("extdata", "precomputed_sample_results_qtl.rda", package = "geneNR"))
message(sample_results)
\dontrun{
result <- geneQTL("sample_data_wheat_qtl", crop="wheat")
# Local mapping workflow:
# gff_path <- system.file("extdata", "sample_crop.gff3", package = "geneNR")
# result <- geneQTL("sample_data_wheat_qtl", genome_source="local", gff3_file=gff_path)
}
}
